# eric7.WebBrowser.Sync.SyncAssistantDialog

Module implementing a wizard dialog to enter the synchronization data.

### Global Attributes

None

### Classes

SyncAssistantDialog | Class implementing a wizard dialog to enter the synchronization data.

### Functions

None

## SyncAssistantDialog

Class implementing a wizard dialog to enter the synchronization data.

### Derived from

QWizard

### Class Attributes

None

### Class Methods

None

### Methods

SyncAssistantDialog | Constructor

### Static Methods

None

#### SyncAssistantDialog (Constructor)

SyncAssistantDialog(parent=None)

Constructor

parent
  reference to the parent widget (QWidget)

Up